Language

Enum Language 

#[non_exhaustive]
pub enum Language {
Show 59 variants Asm, Awk, Batch, Bash, C, CSharp, Clojure, CMake, Cobol, CommonLisp, Cpp, Css, Dart, Diff, Dockerfile, Elixir, Erlang, Go, Groovy, Haskell, Hcl, Html, Ini, Java, JavaScript, Jinja2, Json, Julia, Kotlin, Lua, Markdown, Matlab, ObjectiveC, Ocaml, Perl, Php, Postscript, Powershell, Prolog, Python, R, Ruby, Rust, Scala, Scss, Solidity, Sql, Starlark, Swift, TextProto, Toml, TypeScript, Vb, Verilog, Vhdl, Vue, Xml, Yaml, Zig,
}
Source language predicted by the embedded Magika student model.

Languages parse from their public slugs with str::parse.

let language = "rust".parse::<betlang::Language>()?;

assert_eq!(language, betlang::Language::Rust);
assert_eq!(language.slug(), "rust");

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Asm

Arborium slug "asm".



Awk

Arborium slug "awk".



Batch

Arborium slug "batch".



Bash

Arborium slug "bash".



C

Arborium slug "c".



CSharp

Arborium slug "c-sharp".



Clojure

Arborium slug "clojure".



CMake

Arborium slug "cmake".



Cobol

Arborium slug "cobol".



CommonLisp

Arborium slug "commonlisp".



Cpp

Arborium slug "cpp".



Css

Arborium slug "css".



Dart

Arborium slug "dart".



Diff

Arborium slug "diff".



Dockerfile

Arborium slug "dockerfile".



Elixir

Arborium slug "elixir".



Erlang

Arborium slug "erlang".



Go

Arborium slug "go".



Groovy

Arborium slug "groovy".



Haskell

Arborium slug "haskell".



Hcl

Arborium slug "hcl".



Html

Arborium slug "html".



Ini

Arborium slug "ini".



Java

Arborium slug "java".



JavaScript

Arborium slug "javascript".



Jinja2

Arborium slug "jinja2".



Json

Arborium slug "json".



Julia

Arborium slug "julia".



Kotlin

Arborium slug "kotlin".



Lua

Arborium slug "lua".



Markdown

Arborium slug "markdown".



Matlab

Arborium slug "matlab".



ObjectiveC

Arborium slug "objc".



Ocaml

Arborium slug "ocaml".



Perl

Arborium slug "perl".



Php

Arborium slug "php".



Postscript

Arborium slug "postscript".



Powershell

Arborium slug "powershell".



Prolog

Arborium slug "prolog".



Python

Arborium slug "python".



R

Arborium slug "r".



Ruby

Arborium slug "ruby".



Rust

Arborium slug "rust".



Scala

Arborium slug "scala".



Scss

Arborium slug "scss".



Solidity

Arborium slug "solidity".



Sql

Arborium slug "sql".



Starlark

Arborium slug "starlark".



Swift

Arborium slug "swift".



TextProto

Arborium slug "textproto".



Toml

Arborium slug "toml".



TypeScript

Arborium slug "typescript".



Vb

Arborium slug "vb".



Verilog

Arborium slug "verilog".



Vhdl

Arborium slug "vhdl".



Vue

Arborium slug "vue".



Xml

Arborium slug "xml".



Yaml

Arborium slug "yaml".



Zig

Arborium slug "zig".

Implementations

Source

impl Language

pub const fn slug(self) -> &'static str

Arborium/tree-sitter language slug for this detected language.

assert_eq!(betlang::Language::Rust.slug(), "rust");